@@ -525,6 +525,7 @@ def create_tenx_agent_tool(agent: TenxAgent, name: str, description: str) -> Too
         def execute(self, task: str, metadata: dict = None) -> str:
             import asyncio
             import uuid
+            import warnings
             
             # Generate a unique session ID for this tool execution
             session_id = f"agent_tool_{uuid.uuid4().hex[:8]}"
@@ -532,9 +533,34 @@ def create_tenx_agent_tool(agent: TenxAgent, name: str, description: str) -> Too
             # Prepare metadata for the nested agent, preserving token tracking
             nested_metadata = metadata.copy() if metadata else {}
             
-            # Simple approach: just run the async function
+            async def run_agent_with_cleanup():
+                """Run the agent and ensure proper cleanup of HTTP connections."""
+                try:
+                    result = await self.agent.run(task, session_id=session_id, metadata=nested_metadata)
+                    
+                    # Close the OpenAI client if it exists
+                    if hasattr(self.agent.llm, 'aclose'):
+                        try:
+                            await self.agent.llm.aclose()
+                        except Exception:
+                            pass  # Ignore cleanup errors
+                    
+                    return result
+                except Exception as e:
+                    # Still try to cleanup on error
+                    if hasattr(self.agent.llm, 'aclose'):
+                        try:
+                            await self.agent.llm.aclose()
+                        except Exception:
+                            pass  # Ignore cleanup errors
+                    raise e
+            
+            # Try to run directly first
             try:
-                result = asyncio.run(self.agent.run(task, session_id=session_id, metadata=nested_metadata))
+                # Suppress the "Task exception was never retrieved" warnings
+                with warnings.catch_warnings():
+                    warnings.simplefilter("ignore", RuntimeWarning)
+                    result = asyncio.run(run_agent_with_cleanup())
                 
                 # Propagate token usage back to parent metadata
                 if metadata and 'token_usage' in nested_metadata and 'token_usage' in metadata:
@@ -542,8 +568,9 @@ def create_tenx_agent_tool(agent: TenxAgent, name: str, description: str) -> Too
                     metadata['token_usage']['total_tokens'] += nested_usage['total_tokens']
                     metadata['token_usage']['prompt_tokens'] += nested_usage['prompt_tokens'] 
                     metadata['token_usage']['completion_tokens'] += nested_usage['completion_tokens']
-                
+                print('Tool result: ', result)
                 return str(result)  # Ensure string return for tool interface
+                
             except RuntimeError as e:
                 if "cannot be called from a running event loop" in str(e):
                     # We're in an async context, use a thread
@@ -554,7 +581,9 @@ def create_tenx_agent_tool(agent: TenxAgent, name: str, description: str) -> Too
                     
                     def run_in_thread():
                         try:
-                            result = asyncio.run(self.agent.run(task, session_id=session_id, metadata=nested_metadata))
+                            with warnings.catch_warnings():
+                                warnings.simplefilter("ignore", RuntimeWarning)
+                                result = asyncio.run(run_agent_with_cleanup())
                             result_queue.put(('success', result, nested_metadata))
                         except Exception as e:
                             result_queue.put(('error', e, nested_metadata))
