@@ -62,6 +62,9 @@ class OpenAIModel(LanguageModel):
         
         if not self.api_key:
             raise ValueError("OpenAI API key is required. Set OPENAI_API_KEY environment variable or pass api_key parameter.")
+        
+        # Initialize client as None - will be created on first use
+        self.client = None
     
     def supports_native_tool_calling(self) -> bool:
         """OpenAI supports native function calling."""
@@ -86,16 +89,32 @@ class OpenAIModel(LanguageModel):
             openai_tools.append(openai_tool)
         return openai_tools
     
+    def _get_client(self):
+        """Get or create the OpenAI client."""
+        if self.client is None:
+            import openai
+            self.client = openai.AsyncOpenAI(
+                api_key=self.api_key,
+                organization=self.organization,
+                base_url=self.base_url
+            )
+        return self.client
+    
+    async def aclose(self):
+        """Properly close the OpenAI client and cleanup connections."""
+        if self.client is not None:
+            try:
+                await self.client.aclose()
+            except Exception:
+                pass  # Ignore cleanup errors
+            finally:
+                self.client = None
+    
     async def generate(self, messages: List[Message], tools: Optional[List['Tool']] = None, metadata: Optional[dict] = None) -> GenerationResult: 
-        import openai
         import json
         
-        # Initialize OpenAI client with loaded credentials
-        client = openai.AsyncOpenAI(
-            api_key=self.api_key,
-            organization=self.organization,
-            base_url=self.base_url
-        )
+        # Get the reusable client
+        client = self._get_client()
         
         # Convert messages to OpenAI format
         openai_messages = []
